@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996, 1997, 1999, 2004, 2009, 2010, 2012, 2013, 2019
+ * Copyright (c) 1996, 1997, 1999, 2004, 2009, 2010, 2012, 2013, 2019, 2023
  * The Regents of the University of California. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -26,11 +26,11 @@
  * SUCH DAMAGE.
  */
 #ifndef lint
-static const char copyright[] =
-    "Copyright (c) 1996, 1997, 1999, 2004, 2009, 2010, 2012, 2013, 2019\n\
+static const char copyright[] __attribute__((unused)) =
+    "Copyright (c) 1996, 1997, 1999, 2004, 2009, 2010, 2012, 2013, 2019, 2023\n\
 The Regents of the University of California.  All rights reserved.\n";
-static const char rcsid[] =
-    "@(#) $Id: arpsnmp.c 1505 2019-11-30 18:35:23Z leres $ (LBL)";
+static const char rcsid[] __attribute__((unused)) =
+    "@(#) $Id: arpsnmp.c 1537 2023-09-05 17:50:56Z leres $ (LBL)";
 #endif
 
 /*
