@@ -1,23 +1,25 @@
-/* @(#) $Header: intoa.c,v 1.2 95/04/08 16:48:35 leres Exp $ (LBL) */
+/* @(#) $Id: intoa.c 1072 2010-07-13 01:15:28Z leres $ (LBL) */
 
 #include <sys/types.h>
 
 #include <netinet/in.h>
 
-#include <lbl/gnuc.h>
+#include "gnuc.h"
+#ifdef HAVE_OS_PROTO_H
+#include "os-proto.h"
+#endif
 
-#include "arpwatch.h"
+#include "util.h"
 
 /*
  * A faster replacement for inet_ntoa().
  */
 char *
-intoa(addr)
-	u_long addr;
+intoa(u_int32_t addr)
 {
-	register char *cp;
-	register u_int byte;
-	register int n;
+	char *cp;
+	u_int byte;
+	int n;
 	static char buf[sizeof(".xxx.xxx.xxx.xxx")];
 
 #ifdef NTOHL
